TanaT Documentation
===================

*TanaT* is an extensible Python library for temporal sequence analysis with a primary focus on patient care pathways.

The objective of this library is to gather a collection of tools related to the analysis of timed sequences (or trajectories). 
It has been strongly inspired by the `TraMineR <http://traminer.unige.ch/>`_ library for the analysis of state sequences in R 
and libraries dedicated to time series analysis such as `aeon <https://www.aeon-toolkit.org/>`_ or `tslearn <https://tslearn.readthedocs.io/>`_.

The originality of *TanaT* is to support multi-sequence trajectories that can combine three types of temporal data: states, intervals, and events.
This allows tracking subjects (patients, users, customers, etc.) over time across multiple dimensions, providing a richer and more complete view of their temporal evolution.
The library provides a comprehensive toolkit for multidimensional temporal pattern discovery and analysis.

.. toctree::
   :maxdepth: 2
   :caption: Getting Started
   :hidden:

   getting-started/index

.. toctree::
   :maxdepth: 2
   :caption: User Guide
   :hidden:

   user-guide/index

.. toctree::
   :maxdepth: 2
   :caption: Reference
   :hidden:

   reference/index

.. toctree::
   :maxdepth: 2
   :caption: Community
   :hidden:

   community/index

Quick Links
-----------

**Getting Started**

* :doc:`getting-started/what-is-tanat` - Learn what TanaT is and what it can do
* :doc:`getting-started/installation` - Install TanaT on your system
* :doc:`getting-started/quickstart` - Get up and running in 5 minutes

**User Guide**

* :doc:`user-guide/auto_examples/index` - Browse examples and use cases
* :doc:`user-guide/tutorials/index` - In-depth tutorials and guides

**Reference**

* :doc:`reference/api/index` - Complete API documentation
* :doc:`reference/glossary` - Glossary of terms and concepts